@@ -235,7 +235,7 @@ def should_ignore(fullname):
 
 # Returns the given string with escapes added so that it can safely be placed inside a string in JS code.
 def escape_for_js_string(s):
-  s = s.replace("'", "\\'").replace('"', '\\"').replace('\\', '/')
+  s = s.replace('\\', '/').replace("'", "\\'").replace('"', '\\"')
   return s
 
 # Expand directories into individual files
@@ -564,7 +564,7 @@ if has_preloaded:
     var REMOTE_PACKAGE_NAME = typeof Module['locateFile'] === 'function' ?
                               Module['locateFile'](REMOTE_PACKAGE_BASE) :
                               ((Module['filePackagePrefixURL'] || '') + REMOTE_PACKAGE_BASE);
-  ''' % (data_target, remote_package_name)
+  ''' % (escape_for_js_string(data_target), escape_for_js_string(remote_package_name))
   metadata['remote_package_size'] = remote_package_size
   metadata['package_uuid'] = str(package_uuid)
   ret += '''
